@@ -385,7 +385,7 @@ class SurfingEntrance(object):
         else:
             print('init dm failed, dump tables only')
             syncer = SynchronizerS3ForDM()
-            failed_dfs: ['init dm']
+            failed_dfs: List[str] = ['init dm']
         # 向S3同步所有table
         failed_tables: List[str] = syncer.dump_all_tables()
 
