@@ -578,17 +578,17 @@ class BasicDataApi(metaclass=Singleton):
                 return pd.DataFrame([])
 
     @staticmethod
-    def get_fund_hold_stock_by_id(fund_id):
+    def get_fund_hold_stock_by_id(fund_id: str = ''):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                     FundHoldStock,
-                ).filter(
-                    FundHoldStock.fund_id == fund_id,
                 )
-                df = pd.read_sql(query.statement, query.session.bind)
-                return df
-
+                if fund_id:
+                    query = query.filter(
+                        FundHoldStock.fund_id == fund_id,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundHoldStock.__tablename__}')
                 return pd.DataFrame([])
@@ -720,6 +720,21 @@ class BasicDataApi(metaclass=Singleton):
                 print(f'Failed to get time range data <err_msg> {e} from {FundHoldStock.__tablename__}')
                 return
 
+    def delete_fund_hold_stock(self, date_to_delete: datetime.date, fund_list: List[str]):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                db_session.query(
+                    FundHoldStock
+                ).filter(
+                    FundHoldStock.fund_id.in_(fund_list),
+                    FundHoldStock.datetime == date_to_delete,
+                ).delete(synchronize_session=False)
+                db_session.commit()
+                return True
+            except Exception as e:
+                print(f'Failed to delete data <err_msg> {e} from {FundHoldStock.__tablename__}')
+                return False
+
     def get_fund_hold_bond(self, dt: str = '') -> pd.DataFrame:
        with BasicDatabaseConnector().managed_session() as db_session:
             try:
