@@ -424,6 +424,7 @@ class RawDataApi(metaclass=Singleton):
                     EmFundScale.CODES,
                     EmFundScale.DATES,
                     EmFundScale.FUNDSCALE,
+                    EmFundScale.UNITTOTAL,
                 )
                 if start_date:
                     query = query.filter(
@@ -960,7 +961,7 @@ class RawDataApi(metaclass=Singleton):
                 print(f'Failed to delete data <err_msg> {e} from {EMFundHoldIndustry.__tablename__}')
                 return False
 
-    def get_em_fund_hold_stock(self, end_date: str = '', fund_ids: Tuple[str] = ()):
+    def get_em_fund_hold_stock(self, start_date: str = '', end_date: str = '', fund_ids: Tuple[str] = ()):
         with RawDatabaseConnector().managed_session() as raw_session:
             try:
                 query = raw_session.query(EMFundHoldStock)
@@ -968,15 +969,34 @@ class RawDataApi(metaclass=Singleton):
                     query = query.filter(
                         EMFundHoldStock.CODES.in_(fund_ids),
                     )
+                if start_date:
+                    query = query.filter(
+                        EMFundHoldStock.DATES >= start_date,
+                    )
                 if end_date:
                     query = query.filter(
-                        EMFundHoldStock.DATES <= end_date
+                        EMFundHoldStock.DATES <= end_date,
                     )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {EMFundHoldStock.__tablename__}')
                 return None
 
+    def delete_em_fund_hold_stock(self, date_to_delete: datetime.date, fund_list: List[str]):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                db_session.query(
+                    EMFundHoldStock
+                ).filter(
+                    EMFundHoldStock.CODES.in_(fund_list),
+                    EMFundHoldStock.DATES == date_to_delete,
+                ).delete(synchronize_session=False)
+                db_session.commit()
+                return True
+            except Exception as e:
+                print(f'Failed to delete data <err_msg> {e} from {EMFundHoldStock.__tablename__}')
+                return False
+
     def get_em_fund_hold_bond(self, start_date: str = '', end_date: str = '', fund_ids: Tuple[str] = ()):
         with RawDatabaseConnector().managed_session() as raw_session:
             try:
