@@ -15,7 +15,7 @@ class TradeTrigger:
 
     @staticmethod
     def is_end(trigger):
-        return trigger / TradeTrigger.FundEnd > 1
+        return trigger / TradeTrigger.FundEnd >= 1
 
     @staticmethod
     def parse(trigger):
