@@ -247,6 +247,7 @@ class BasicDataPart1:
         df = df.rename(columns={'short_name': 'desc_name'})
         # 先全体置为false，后续可以手工修改
         df['is_select'] = False
+        df['is_stock_factor_universe'] = False
         df['tag_method'] = 'PE百分位'
         # index_id是人工起的，所以只能作为参数传进来
         df['index_id'] = index_ids
@@ -587,7 +588,7 @@ class BasicDataPart1:
             # 将场内变为场外的
             df['CODES'] = df.CODES.transform(lambda x: x.split('.')[0] + '.OF' if '.OF' not in x else x)
             # pivot on all remaining columns
-            df = df.drop(columns='FUNDSCALE').pivot(index='DATES', columns='CODES').fillna(method='ffill')
+            df = df.drop(columns=['FUNDSCALE', 'UNITTOTAL']).pivot(index='DATES', columns='CODES').fillna(method='ffill')
             df = df.iloc[[-1], :].stack().reset_index()
             df['fund_id'] = df[['DATES', 'CODES']].apply(lambda x: self._data_helper._get_fund_id_from_order_book_id(x.CODES.split('.')[0], x.DATES), axis=1)
             df = df[df.fund_id.notna()]
@@ -718,12 +719,11 @@ class BasicDataPart1:
             else:
                 real_date = RawDataHelper.get_prev_target_date(end_date, QUARTER_UPDATE_DATE_LIST)
                 fund_scale = self._raw_data_api.get_em_fund_scale(start_date=real_date, end_date=real_date)
-            fund_scale = fund_scale.pivot(index='DATES', columns='CODES', values='FUNDSCALE').fillna(method='ffill').stack()
-            fund_scale = pd.DataFrame(fund_scale, columns=['FUNDSCALE']).reset_index()
+            fund_scale = fund_scale.pivot(index='DATES', columns='CODES', values=['FUNDSCALE', 'UNITTOTAL']).fillna(method='ffill').stack().reset_index()
             fund_scale['fund_id'] = fund_scale.apply(
                 lambda x: self._data_helper._get_fund_id_from_order_book_id(x['CODES'].split('.')[0], x['DATES']), axis=1)
-            fund_scale = fund_scale[fund_scale.fund_id.notna() & fund_scale.FUNDSCALE.notna()]
-            fund_scale = fund_scale.drop(columns=['CODES']).rename(columns={'DATES': 'datetime', 'FUNDSCALE': 'size'})
+            fund_scale = fund_scale[fund_scale.fund_id.notna()]
+            fund_scale = fund_scale.drop(columns=['CODES']).rename(columns={'DATES': 'datetime', 'FUNDSCALE': 'size', 'UNITTOTAL': 'unit_total'})
 
             if fund_holding_rate is not None and not fund_holding_rate.empty:
                 df = fund_scale.set_index(['fund_id', 'datetime']).join(fund_holding_rate.set_index(['fund_id', 'datetime']), how='left').reset_index()
@@ -734,7 +734,7 @@ class BasicDataPart1:
             if not is_history:
                 now_df = BasicDataApi().get_history_fund_size(start_date=real_date, end_date=real_date)
                 if now_df is not None:
-                    now_df = now_df.astype({'size': 'float64', 'personal_holds': 'float64', 'institution_holds': 'float64', 'hold_num': 'float64'})
+                    now_df = now_df.replace({None: np.nan}).infer_objects()
                     # 过滤出来新增基金benchmark以及旧基金的benchmark发生变化的情况
                     now_df = now_df.drop(columns=['_update_time']).sort_values(by=['fund_id', 'datetime']).drop_duplicates(subset='fund_id', keep='last')
                     # merge on all columns
@@ -821,18 +821,38 @@ class BasicDataPart1:
             traceback.print_exc()
             return False
 
-    def fund_hold_stock(self, end_date: str):
-        #history, update only on report date
-        em_hold_stock = self._raw_data_api.get_em_fund_hold_stock(end_date)
-        em_hold_stock['CODES'] = em_hold_stock.apply(lambda x :
-                            self._data_helper._get_fund_id_from_order_book_id(x.CODES.split('.')[0], x.DATES), axis=1)
-        em_hold_stock = em_hold_stock.dropna(subset=['CODES']).drop('_update_time', axis=1)
-        name_dict = {
-            'CODES':'fund_id',
-            'DATES':'datetime',
-        }
-        em_hold_stock = em_hold_stock.rename(columns=name_dict)
-        self._data_helper._upload_basic(em_hold_stock, FundHoldStock.__table__.name)
+    def fund_hold_stock(self, start_date: str, end_date: str, is_history=True):
+        try:
+            if is_history:
+                # history, update only on report date
+                df = self._raw_data_api.get_em_fund_hold_stock(start_date, end_date)
+            else:
+                real_date = RawDataHelper.get_prev_target_date(end_date, QUARTER_UPDATE_DATE_LIST)
+                df = self._raw_data_api.get_em_fund_hold_stock(real_date, real_date)
+            df['CODES'] = df.apply(lambda x: self._data_helper._get_fund_id_from_order_book_id(x.CODES.split('.')[0], x.DATES), axis=1)
+            df = df.dropna(subset=['CODES']).drop(columns='_update_time')
+            name_dict = {
+                'CODES': 'fund_id',
+                'DATES': 'datetime',
+            }
+            df = df.rename(columns=name_dict)
+            if not is_history:
+                now_df = BasicDataApi().get_fund_hold_stock(dt=real_date)
+                if now_df is not None:
+                    # 过滤出来新增基金benchmark以及旧基金的benchmark发生变化的情况
+                    now_df = now_df.drop(columns=['_update_time']).sort_values(by=['fund_id', 'datetime']).drop_duplicates(subset='fund_id', keep='last')
+                    # merge on all columns
+                    df = df.merge(now_df, how='left', indicator=True, validate='one_to_one')
+                    df = df[df._merge == 'left_only'].drop(columns=['_merge'])
+                # TODO: 最好原子提交下边两步
+                BasicDataApi().delete_fund_hold_stock(real_date, df.fund_id.to_list())
+            print(df)
+            self._data_helper._upload_basic(df, FundHoldStock.__table__.name)
+            return True
+        except Exception as e:
+            print(e)
+            traceback.print_exc()
+            return False
 
     def fund_hold_bond(self, start_date: str, end_date: str, is_history=True):
         try:
@@ -962,6 +982,9 @@ class BasicDataPart1:
                 if not self.fund_size_hold_rate(end_date, end_date, is_history=False):
                     failed_tasks.append('fund_size_hold_rate')
 
+                if not self.fund_hold_stock(end_date, end_date, is_history=False):
+                    failed_tasks.append('fund_stock')
+
                 if not self.fund_hold_bond(end_date, end_date, is_history=False):
                     failed_tasks.append('fund_bond')
 
