@@ -11,6 +11,21 @@ from ...view.derived_models import FundAlpha, FundIndicator, FundScoreNew, FundM
 from ....constant import ExchangeStatus
 
 class FundDailyCollectionProcessor(object):
+
+    FUND_CLASSIFIER = {
+        'QDII': ['国际(QDII)股票型基金', '国际(QDII)债券型基金', '国际(QDII)另类投资基金', '国际(QDII)混合型基金', ],
+        'stock': ['普通股票型基金', '偏股混合型基金',  '被动指数型基金', '增强指数型基金', '平衡混合型基金', '灵活配置型基金', '股票多空'], 
+        'bond': ['中长期纯债型基金', '短期纯债型基金', '偏债混合型基金', '增强指数型债券基金', '被动指数型债券基金','混合债券型二级基金', '混合债券型一级基金'],
+        'mmf': ['货币市场型基金'],
+        'index': ['被动指数型基金', '增强指数型基金', '增强指数型债券基金', '被动指数型债券基金', '商品型基金', 'REITs'],
+    }
+
+    def __init__(self):
+        self.fund_type_dic = {}
+        for k, v in self.FUND_CLASSIFIER.items():
+            for v_i in v:
+                self.fund_type_dic[v_i] = k
+
     def get_fund_df(self):
         with BasicDatabaseConnector().managed_session() as mn_session:
             try:
@@ -66,11 +81,13 @@ class FundDailyCollectionProcessor(object):
 
                 query = mn_session.query(
                     FundBenchmark.fund_id,
-                    FundBenchmark.benchmark_s,
+                    FundBenchmark.benchmark_s_raw,
                 )
                 df = pd.read_sql(query.statement, query.session.bind)
-                df['benchmark_s'] = df['benchmark_s'].apply(select_one_benchmark)
+                df['benchmark_s'] = df['benchmark_s_raw'].apply(select_one_benchmark)
+                df.loc[df.benchmark_s == '-1','benchmark_s'] = None
                 df['benchmark_name'] = df['benchmark_s'].apply(get_index_name, args=(index_df,))
+                df = df.drop(columns=['benchmark_s_raw'])
                 return df
             except Exception as e:
                 print('Failed fill get data <err_msg> {}'.format(e))
@@ -478,13 +495,16 @@ class FundDailyCollectionProcessor(object):
             df = df.groupby('wind_class_II').apply(self.calc_group_num)
 
             print(df)
-            df = df.apply(self.select_benchmark, axis=1)
+            # 对于 track err 和 benchmark_name 只有一种存在的基金， 全都变成空
+            con = df[['benchmark_name','tag_track_err']].isnull().sum(axis=1)
+            df.loc[con[con == 1].index,'benchmark_name'] = None
+            df.loc[con[con == 1].index,'benchmark_s'] = None
+            df.loc[con[con == 1].index,'tag_track_err'] = None
             print(df)
             df = df.drop(['redeem_status', 'subscribe_status'], axis=1)
             df = df.sort_values(['fund_id'])
-            df = df.drop_duplicates(subset=['order_book_id'], keep='first')
             df = df.dropna(subset=['order_book_id'])
-
+            df.loc[:,'fund_type'] = df.wind_class_II.map(self.fund_type_dic)
             # df.to_csv('./hhh.csv')
             self.append_data(FundDailyCollection.__tablename__, df)
 
