@@ -123,7 +123,7 @@ def fund_info_update(fund_info: pd.DataFrame):
     return fund_info
 
 def active_fund_info(fund_info: pd.DataFrame, fund_benchmark: pd.DataFrame):
-    active_stock_fund_list = ['普通股票型基金', '灵活配置型基金', '平衡混合型基金', '偏股混合型基金']
+    active_stock_fund_list = ['普通股票型基金', '偏股混合型基金', '增强指数型基金','灵活配置型基金', '平衡混合型基金']
     stock_index = ['csi500','hs300']
     gem_index_list = ['cnext_lowv_bc','cnext_mome_gr','cnext_r','gei','gem','gem_50'] #创业板相关基准
     
@@ -200,6 +200,30 @@ def active_fund_info(fund_info: pd.DataFrame, fund_benchmark: pd.DataFrame):
         _res.append(_df)
     active_fund_info = pd.concat(_res)[['desc_name','start_date','end_date','wind_class_1','wind_class_2','index_id','weight_1']].rename(columns={'weight_1':'weight'}).reset_index()
     
+    # 人工增加中证500 hs300 主动型， 基金基准人工扩容 TODO
+    csi500 = ['000001!0',
+                '000021!0',
+                '004065!0',
+                '004272!0',
+                '004273!0',
+                '005188!0',
+                '005189!0',
+                '005355!0',
+                '005356!0',
+                '005385!0',
+                '040007!0',
+                '070002!0',
+                '110011!0',
+                '257010!0',
+                '550009!0']
+    
+    hs300 = ['000011!0', '000551!0', '000761!0', '090003!0']
+    # fund_info.loc[csi500, 'index_id'] = 'csi500'
+    # fund_info.loc[hs300, 'index_id'] = 'hs300' 
+    # csi500_df = fund_info.loc[csi500][['desc_name','start_date','end_date','wind_class_1','wind_class_2','index_id']].reset_index()
+    # hs300_df = fund_info.loc[hs300][['desc_name','start_date','end_date','wind_class_1','wind_class_2','index_id']].reset_index()
+    # active_fund_info = active_fund_info.append(csi500_df).append(hs300_df)
+    
     # 只选择成立一年的
     _begin_date = datetime.datetime.today().date() - datetime.timedelta(days=365)
     active_fund_info = active_fund_info[active_fund_info['start_date'] < _begin_date]
