@@ -243,6 +243,8 @@ class FundDataManager(DataManager):
             return query.filter(
                 FundManagerFundRank.datetime >= self.start_date,
                 FundManagerFundRank.datetime <= self.end_date,
+                #ManagerFundDetail.datetime >= self.start_date,
+                #ManagerFundDetail.datetime <= self.end_date,
             ), _fund_manager_fund_rank_info_filter_etl
 
         with RawDatabaseConnector().managed_session() as raw_session:
@@ -432,53 +434,57 @@ class FundDataManager(DataManager):
                 FundManagerScore.sharpe,
                 FundManagerScore.fund_type,
                 FundManagerScore.fund_size,
+                FundManagerScore.now_comp_year,
+                FundManagerScore.year_ret_std,
             )
-            _fund_manager_score_query, _fund_manager_score_filter_func = _fund_manager_score_filter(_fund_manager_score_query) 
+            _fund_manager_score_query, _fund_manager_score_filter_func = _fund_manager_score_filter(_fund_manager_score_query)
             self.dts.fund_manager_score = self._s3_retriever.fetch_table(_fund_manager_score_query, _fund_manager_score_filter_func).drop(columns='fund_type')
             _dt =self.dts.trading_days[self.dts.trading_days.datetime >= self.dts.fund_manager_score.datetime.min()].datetime
             self.dts.fund_manager_score = self.dts.fund_manager_score.pivot_table(index='datetime', columns='manager_id').reindex(_dt).fillna(method='ffill').reindex(trim_trading_days).stack().reset_index()
             _tm_deriv_apply_active_indicator = time.time()
             _fund_manager_info_query = derived_session.query(
-                FundManagerInfo.mng_id,
-                FundManagerInfo.start_date,
-                FundManagerInfo.fund_id,
-                FundManagerInfo.end_date,
-                FundManagerInfo.mng_name,
+                FundManagerInfo
             )
             self.dts.fund_manager_info = self._s3_retriever.fetch_table(_fund_manager_info_query)
+            _df = self.dts.fund_manager_info[self.dts.fund_manager_info['end_date'] == datetime.date(2040,1,1)][['mng_id','fund_id']].groupby('mng_id').count()
             self.dts.fund_manager_info = self.dts.fund_manager_info.set_index('mng_id')
+            self.dts.fund_manager_info = self.dts.fund_manager_info.join(_df.rename(columns={'fund_id':'fund_num'}))
             _tm_deriv_apply_manager_info = time.time()
             _fund_manager_fund_rank_info_query = derived_session.query(
+                #ManagerFundDetail.mng_id,
+                #ManagerFundDetail.datetime,
+                #ManagerFundDetail.stock_fund_list,
                 FundManagerFundRank.mng_id,
                 FundManagerFundRank.datetime,
                 FundManagerFundRank.fund_list,
             )
             _fund_manager_fund_rank_info_query, _fund_manager_fund_rank_info_filter_func = _fund_manager_fund_rank_info_filter(_fund_manager_fund_rank_info_query)
             self.dts.fund_manager_rank = self._s3_retriever.fetch_table(_fund_manager_fund_rank_info_query, _fund_manager_fund_rank_info_filter_func)
-            self.dts.fund_manager_rank['fund_list'] = [ json.loads(i) for i in self.dts.fund_manager_rank.fund_list]
-            self.dts.fund_manager_rank = self.dts.fund_manager_rank.set_index(['datetime','mng_id'])
+            #self.dts.fund_manager_rank['stock_fund_list'] = [ json.loads(i) for i in self.dts.fund_manager_rank.stock_fund_list]
+            self.dts.fund_manager_rank['stock_fund_list'] = [ json.loads(i) for i in self.dts.fund_manager_rank.fund_list]
+            self.dts.fund_manager_rank = self.dts.fund_manager_rank.set_index(['datetime','mng_id']).drop(columns=['fund_list'])
             _fund_manager_score = self.dts.fund_manager_score.rename(columns={'manager_id':'mng_id'}).set_index(['datetime','mng_id'])
             _df = _fund_manager_score.join(self.dts.fund_manager_rank).copy()
-            _df = _df.explode('fund_list').dropna()
-            _df = _df.reset_index().drop('mng_id',axis=1).rename(columns={'fund_list':'fund_id'})
+            _df = _df.explode('stock_fund_list').dropna()
+            _df = _df.reset_index().drop('mng_id',axis=1).rename(columns={'stock_fund_list':'fund_id'})
             _cols = _df.columns.tolist()
             _mng_score_dic = { c : f'mng_{c}' for c in _cols if c not in ['datetime', 'fund_id']}
             _df = _df.rename(columns = _mng_score_dic)
             _df['datetime'] = _df.datetime.dt.date
             self.dts.fund_indicator = pd.merge(self.dts.fund_indicator, _df,how='left',left_on=['fund_id','datetime'],right_on=['fund_id','datetime'])
             _index_list = ['hs300','csi500','gem']
-            
+
             self.dts.fund_indicator['active'] = self.dts.fund_indicator.fund_id.transform(lambda x: 0 if x in _normal_funds_index_dic and _normal_funds_index_dic[x] in _index_list else 1)
             self.dts.fund_indicator['index_id'] = self.dts.fund_indicator.fund_id.apply(lambda x: self.dts.fund_index_map.get(x, None))
             _fund_indicator_whole = self.dts.fund_indicator.copy()
             self.dts.fund_indicator = self.dts.fund_indicator.dropna(subset=['index_id'])
             conv_indicator_df = self.ipo_conv_indicator_process(conv_dict, 'conv_bond', _fund_indicator_whole)
             self.dts.fund_indicator = self.dts.fund_indicator.append(conv_indicator_df)
-            self.dts.fund_indicator = pd.merge(self.dts.fund_indicator, ipo_weight_last_year_df, 
+            self.dts.fund_indicator = pd.merge(self.dts.fund_indicator, ipo_weight_last_year_df,
                                                 how='left', left_on=['fund_id','datetime'], right_on=['fund_id','datetime'])
             self.dts.fund_indicator['ipo_weight'] = self.dts.fund_indicator['ipo_weight'].fillna(0)
             _fund_size = self.dts.fund_size.stack().reset_index().rename(columns={0:'fund_size','level_0':'datetime'})
-            self.dts.fund_indicator = pd.merge(self.dts.fund_indicator, _fund_size, 
+            self.dts.fund_indicator = pd.merge(self.dts.fund_indicator, _fund_size,
                                             how='left', left_on=['fund_id','datetime'], right_on=['fund_id','datetime'])
             self.dts.fund_indicator['fund_size'] = self.dts.fund_indicator['fund_size'].fillna(0)
             _tm_deriv_apply_manager_rank = time.time()
@@ -564,7 +570,7 @@ class FundDataManager(DataManager):
             print(f'[time] fix_d: {_tm_fix - _tm_derived}')
             print(f'[time] score: {_tm_finish - _tm_fix}')
             print(f'[time] total: {_tm_finish - _tm_start}')
-    
+
     def _make_annual_fac(self, the_dict, x):
         fund_id = x.fund_id
         dt = x.datetime
@@ -745,10 +751,11 @@ class FundDataManager(DataManager):
             BarraCNE5FactorProcessor.fund_analysis_plot(fund_ret, factor_ret_contri)
         return params, spec_ret
 
-    def fund_analysis_by_stock_factors(self, fund_id: str, factor_names: Tuple[str]) -> pd.DataFrame:
+    def fund_analysis_by_stock_factors(self, fund_id: str, factor_names: Tuple[str], universe: str = 'default') -> Optional[pd.DataFrame]:
+        '''对基金计算因子暴露'''
         try:
             try:
-                fund_nav = self.dts.fund_nav.loc[:, fund_id]
+                fund_nav: pd.Series = self.dts.fund_nav.loc[:, fund_id]
             except KeyError:
                 print(f'[fund_analysis_new] do not have nav of {fund_id}, try to retrieve it')
                 if not self.confirm_fund_nav_exists(fund_id):
@@ -757,7 +764,20 @@ class FundDataManager(DataManager):
         except KeyError:
             print(f'[fund_analysis_new] do not have nav of {fund_id} as before, can not do analysis')
             return
-        return StockFactorApi.decomp_ret(fund_nav.pct_change(), factor_names)
+        return StockFactorApi.decomp_ret(fund_nav.pct_change(), factor_names, universe)
+
+    def index_analysis_by_stock_factors(self, index_id: str, factor_names: Tuple[str]) -> Optional[pd.DataFrame]:
+        '''对指数计算因子暴露'''
+        try:
+            index_price: pd.Series = self.dts.index_price.loc[:, index_id]
+        except KeyError:
+            print(f'[index_analysis_new] do not have price of {index_id}, can not do analysis')
+            return
+        return StockFactorApi.decomp_ret(index_price.pct_change(), factor_names, 'default')
+
+    def fund_pos_analysis_by_stock_factors(self, fund_id: str, factor_names: Tuple[str], report_date: datetime.date, universe: str = 'default') -> Optional[pd.DataFrame]:
+        '''对基金持仓计算因子暴露'''
+        return StockFactorApi.fac_pos(fund_id, factor_names, report_date, universe)
 
     def white_and_black_list_filter(self, score, score_raw, disproved_list):
         return self._score_manager._white_and_black_list_filter(score, score_raw, disproved_list)
