@@ -61,6 +61,8 @@ class ScoreFunc:
     mng_sharpe: float = 0
     mng_trade_year: float = 0
     mng_fund_size: float = 0
+    mng_now_comp_year: float = 0
+    mng_year_ret_std: float = 0
     alpha_bond: float = 0
     beta_bond: float = 0
     alpha_hs300: float = 0
@@ -109,6 +111,8 @@ class ScoreFunc:
                 + data.mng_sharpe.mul(other=self.mng_sharpe, fill_value=0) \
                 + data.mng_trade_year.mul(other=self.mng_trade_year, fill_value=0) \
                 + data.mng_fund_size.mul(other=self.mng_fund_size, fill_value=0) \
+                + data.mng_now_comp_year.mul(other=self.mng_now_comp_year, fill_value=0) \
+                + data.mng_year_ret_std.mul(other=self.mng_year_ret_std, fill_value=0) \
                 + data.active * self.active
                 # + self.down_risk * data.down_risk \
                 # + self.info_ratio * data.info_ratio \
@@ -176,12 +180,12 @@ class FundScoreManager:
             'hs300': {
                 'default': ScoreFunc(track_err=-0.4,beta=-0.6),
                 'enhanced':ScoreFunc(alpha=0.6, beta=-0.3),
-                'active': ScoreFunc(mng_trade_year=0.15, mng_annualized_ret=0.15,alpha=0.3,mng_model_alpha=0.3,mng_model_beta=0.1,active=10),
+                'active': ScoreFunc(mng_trade_year=0.1, mng_sharpe=0.3,alpha=0.4,mng_year_ret_std=-0.2,active=10),
             },
             'csi500': {
                 'default': ScoreFunc(info_ratio=0.2,track_err=-0.7, fee_rate=-0.1),
                 'enhanced':ScoreFunc(alpha=0.9, beta=-0.1),
-                'active': ScoreFunc(mng_trade_year=0.15, mng_annualized_ret=0.15, mng_sharpe=0.15,alpha=0.1,mng_model_alpha=0.3,mng_model_beta=0.15,active=10),
+                'active': ScoreFunc(mng_trade_year=0.1, mng_sharpe=0.3,alpha=0.4,mng_year_ret_std=-0.2,active=10),
             }, 
             'gem': {
                 'default': ScoreFunc(info_ratio=0.2,track_err=-0.7, fee_rate=-0.1),
@@ -293,8 +297,9 @@ class FundScoreManager:
         index_id = 'active'
         type_i = score_select[index_id]
         fund_ids = self._filter_size_and_com_hold(dt, index_id, active_fund_id_list)
-        manager_score = self.score_manager_cache[dt][score_select[index_id]].to_dict()
+        #print(f'dt {dt} index_id {index_id} score_select {score_select} self.score_manager_cache[dt] {self.score_manager_cache[dt]}')  
         try:
+            manager_score = self.score_manager_cache[dt][score_select[index_id]].to_dict()
             _manager_funds = self.dts.fund_manager_rank.loc[dt].to_dict()['fund_list']
             # 根据对规模和持有人结构筛选条件过滤基金
             manager_funds = {}
@@ -353,6 +358,8 @@ class FundScoreManager:
             cur_d_sta['beta'] = cur_d['beta']
             cur_d_sta['year_length'] = cur_d['year_length']
             cur_d_sta['active'] = cur_d['active']
+            cur_d_sta['mng_fund_size'] = cur_d['mng_fund_size']
+            less_mng_year = cur_d[cur_d['mng_trade_year'] < 1].index.tolist()
             cur_d = cur_d_sta
             score_raw_sum = {}
             score_sum = {}
@@ -375,9 +382,14 @@ class FundScoreManager:
                     punish_funds = cur_d[cur_d.year_length < self.score_penalty_param.JudgeYearLength].index.tolist()
                     for _fund_id in punish_funds:
                         score_raw[_fund_id] += self.score_penalty_param.Penalty
-                    # 以下是vectorize calc, 但看起来没有明显的加速效果
-                    # punish_funds = pd.Series(self.score_penalty_param.Penalty, index=cur_d[cur_d.year_length < self.score_penalty_param.JudgeYearLength].index)
-                    # score_raw = score_raw.add(punish_funds, fill_value=0)
+                    if index_id in ['hs300','csi500'] and type_i in ['active']:
+                        punish_funds_1 = cur_d_sta[cur_d_sta['mng_fund_size'] < 5e8].index.tolist()
+                        punish_funds_1 = cur_d_sta[cur_d_sta['mng_fund_size'] < 5e8].index.tolist()
+                        # 对于管理规模不到5千万和 年限不到1年到经理，进行惩罚
+                        for _fund_id in punish_funds_1:
+                            score_raw[_fund_id] += self.score_penalty_param.Penalty
+                        for _fund_id in less_mng_year:
+                            score_raw[_fund_id] += self.score_penalty_param.Penalty
                 score = (score_raw - score_raw.min()) / (score_raw.max() - score_raw.min())
                 if is_filter_c:
                     score = self._filter_score(score)
