@@ -16,6 +16,8 @@ class AssetDict:
     mmf: float=0.0
     hsi: float=0.0
     active: float=0.0
+    conv_bond: float=0.0
+    
     def __repr__(self):
         s = f'<{self.__class__.__name__}'
         for k, v in self.__dict__.items():
@@ -41,6 +43,7 @@ class AssetTimeSpan:
     mmf: int=1
     hsi: int=1
     active: int=1
+    conv_bond: int=1
 
 @dataclasses.dataclass
 class AssetWeight(AssetDict):
@@ -340,6 +343,13 @@ class FundWeight:
     def get(self, fund_id: str):
         return self.funds.get(fund_id)
 
+    def rebalance(self):
+        s = 0
+        for k,v in self.funds.items():
+            s += v.fund_wgt
+        for k,v in self.funds.items():
+            v.fund_wgt /= s
+
     def __repr__(self):
         s = f'<FW'
         for fund_id, wgt_item in self.funds.items():
@@ -579,6 +589,7 @@ class ScoreSelect:
     gold:str            =   ScoreType.Default
     hsi:str             =   ScoreType.Default
     active:str          =   ScoreType.Default
+    conv_bond:str       =   ScoreType.Default
 
 if __name__ == '__main__':
     a = AssetWeight(hs300=0.1, csi500=0.1, cash=0.8)
