@@ -56,6 +56,7 @@ class IndexInfo(Base):
     maker_name = Column(CHAR(32), nullable=False)  # 编制机构
     # publish_date = Column(DATE, nullable=False)  # 发布日期
     is_select = Column(BOOLEAN, nullable=False)  # 是否属于精选
+    is_stock_factor_universe = Column(BOOLEAN)  # 是否是股票因子universe
     em_id = Column(CHAR(20))  # ChoiceID
     em_plate_id = Column(CHAR(20))  # Choice板块ID
     index_profile = Column(TEXT)  # 指数概况
@@ -349,6 +350,7 @@ class Fund_size_and_hold_rate(Base):
     fund_id = Column(CHAR(10), primary_key=True)  # 基金id
     datetime = Column(DATE, primary_key=True)  # 日期
     size = Column(DOUBLE(asdecimal=False)) # 最新规模
+    unit_total = Column(DOUBLE(asdecimal=False))  # 基金份额
     personal_holds = Column(DOUBLE(asdecimal=False)) # 个人持有比例 单位百分比
     institution_holds = Column(DOUBLE(asdecimal=False)) # 机构持有比例 单位百分比
     hold_num = Column(DOUBLE(asdecimal=False))  # 基金份额持有人户数
