@@ -509,6 +509,17 @@ class FundManagerFundRank(Base):
     datetime = Column(DATE, primary_key=True) # 时间
     fund_list = Column(TEXT)
 
+class ManagerFundDetail(Base):
+    '''基金经理基金排名'''
+    __tablename__ = 'manager_fund_detail'
+
+    mng_id = Column(CHAR(10), primary_key=True) # 基金经理id
+    datetime = Column(DATE, primary_key=True) # 时间
+    stock_fund_list = Column(TEXT)
+    # bond_fund_list = Column(TEXT)
+    # mmf_fund_list = Column(TEXT)
+    # qdii_fund_list = Column(TEXT)
+    # mix_fund_list = Column(TEXT)
 
 class NewShareFundRank(Base):
     """打新基金榜单"""
@@ -659,4 +670,5 @@ class StockFactorInfo(Base):
     f_id = Column(CHAR(16), primary_key=True)  # 因子ID
     f_type = Column(Enum(StockFactorType), nullable=False)  # 因子所属分类
     f_name = Column(TEXT, nullable=False)  # 因子名称
+    is_selected_by_default = Column(BOOLEAN, nullable=False)  # 是否默认被选中
     f_desc = Column(TEXT)  # 因子简介
