@@ -495,6 +495,7 @@ class EmFundScale(Base):
     DATES = Column(DATE, primary_key=True)  # 日期
 
     FUNDSCALE = Column(DOUBLE(asdecimal=False))  # 基金规模
+    UNITTOTAL = Column(DOUBLE(asdecimal=False))  # 基金份额
     PURCHSTATUS = Column(CHAR(16))  # 申购状态
     REDEMSTATUS = Column(CHAR(16))  # 赎回状态
     LPLIMIT = Column(DOUBLE(asdecimal=False))  # 暂停大额申购上限
@@ -701,6 +702,7 @@ class EmStockFinFac(Base):
     INCOMESTATEMENT_9 = Column('income_statement_9', DOUBLE(asdecimal=False)) # 营业收入
     INCOMESTATEMENT_14 = Column('income_statement_14', DOUBLE(asdecimal=False)) # 财务费用
     INCOMESTATEMENT_48 = Column('income_statement_48', DOUBLE(asdecimal=False)) # 营业利润
+    INCOMESTATEMENT_56 = Column('income_statement_56', DOUBLE(asdecimal=False)) # 所得税(费用)
     INCOMESTATEMENT_60 = Column('income_statement_60', DOUBLE(asdecimal=False)) # 净利润
     INCOMESTATEMENT_61 = Column('income_statement_61', DOUBLE(asdecimal=False)) # 归属于母公司股东的净利润
     INCOMESTATEMENT_83 = Column('income_statement_83', DOUBLE(asdecimal=False)) # 营业总收入
@@ -709,9 +711,13 @@ class EmStockFinFac(Base):
     CASHFLOWSTATEMENT_9 = Column('cashflow_statement_9', DOUBLE(asdecimal=False)) # 销售商品、提供劳务收到的现金
     CASHFLOWSTATEMENT_39 = Column('cashflow_statement_39', DOUBLE(asdecimal=False)) # 经营活动产生的现金流量净额
     CASHFLOWSTATEMENT_59 = Column('cashflow_statement_59', DOUBLE(asdecimal=False)) # 投资活动产生的现金流量净额
+    CASHFLOWSTATEMENT_70 = Column('cashflow_statement_70', DOUBLE(asdecimal=False)) # 分配股利、利润或偿付利息支付的现金
     CASHFLOWSTATEMENT_77 = Column('cashflow_statement_77', DOUBLE(asdecimal=False)) # 筹资活动产生的现金流量净额
     CASHFLOWSTATEMENT_82 = Column('cashflow_statement_82', DOUBLE(asdecimal=False)) # 现金及现金等价物净增加额
     CASHFLOWSTATEMENT_86 = Column('cashflow_statement_86', DOUBLE(asdecimal=False)) # 资产减值准备
+    CASHFLOWSTATEMENT_87 = Column('cashflow_statement_87', DOUBLE(asdecimal=False)) # 固定资产折旧
+    CASHFLOWSTATEMENT_88 = Column('cashflow_statement_88', DOUBLE(asdecimal=False)) # 无形资产摊销
+    CASHFLOWSTATEMENT_89 = Column('cashflow_statement_89', DOUBLE(asdecimal=False)) # 长期待摊费用摊销
 
     __table_args__ = (
         Index('idx_em_stock_fin_fac_datetime', 'datetime'),
@@ -1498,3 +1504,43 @@ class EmStockYearly(Base):
     CODES = Column('stock_id', CHAR(10), primary_key=True)  # EM股票ID
     year = Column(YEAR, primary_key=True)  # 年度
     DIVANNUACCUM = Column('div_annu_accum', DOUBLE(asdecimal=False))  # 年度累计分红
+
+
+class SuntimeReportEarningsAdjust(Base):
+    '''朝阳永续报告盈利预测调整表'''
+
+    __tablename__ = 'suntime_report_earnings_adjust'
+
+    stock_code = Column('stock_id', CHAR(10), primary_key=True)  # 股票代码
+    report_year = Column(YEAR, primary_key=True)  # 预测年度
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    report_id = Column(Integer, nullable=False)  # 报告ID
+    title = Column(TEXT) # 标题
+    report_type = Column(SMALLINT, nullable=False)  # 报告类型
+    organ_id = Column(Integer, nullable=False)  # 机构ID
+    author = Column(TEXT)  # 研究员姓名
+    current_create_date = Column(DATE, nullable=False)  # 本次预测日期
+    previous_create_date = Column(DATE)  # 上次预测日期
+    current_forecast_np = Column(DOUBLE(asdecimal=False))  # 本次预测净利润(归属母公司净利润)
+    previous_forecast_np = Column(DOUBLE(asdecimal=False))  # 上次预测净利润(归属母公司净利润)
+    np_adjust_rate = Column(DOUBLE(asdecimal=False))  # 预期净利润调整比率(归属母公司净利润)
+    np_adjust_mark = Column(TINYINT)  # 预期净利润调整调整标记(归属母公司净利润)
+    current_forecast_eps = Column(DOUBLE(asdecimal=False))  # 本次预测 EPS
+    previous_forecast_eps = Column(DOUBLE(asdecimal=False))  # 上次预测 EPS
+    eps_adjust_rate = Column(DOUBLE(asdecimal=False))  # EPS 调整比率
+    is_capital_different = Column(TINYINT)  # 本次和上次预测股本是否有差异
+    eps_adjust_mark = Column(TINYINT)  # EPS 调整标记
+
+
+class SuntimeReportOrganInfo(Base):
+    '''朝阳永续机构信息表'''
+
+    __tablename__ = 'suntime_report_organ_info'
+
+    organ_id = Column(Integer, primary_key=True)  # 机构ID
+    organ_name = Column(TEXT, nullable=False)  # 机构简称
+    py_organ_name = Column(TEXT, nullable=False)  # 机构拼音
+    organ_type = Column(SMALLINT)  # 机构分类
+    is_con_forecast_organ = Column(BOOLEAN, nullable=False)  # 是否一致预期选用机构
+    is_over_50_reports = Column(BOOLEAN, nullable=False)  # 是否一年内撰写报告 50 篇以上
+    is_hk_reports_organ = Column(BOOLEAN, nullable=False)  # 是否港股报告撰写机构
