@@ -23,32 +23,36 @@ class FundDailyCollection(Base):
 
     wind_class_I = Column(CHAR(64))  # Wind基金类型  (混合型基金 债券型基金 股票型基金 货币市场型基金 国际(QDII)基金 另类投资基金)
     wind_class_II = Column(CHAR(64))  # Wind基金二级类型
-    institution_rating = Column(CHAR(20))  # 机构评级
+    institution_rating = Column(CHAR(20))  # 机构评级 暂无
     found_to_now = Column(DOUBLE(asdecimal=False))  # 成立年限
-    average_size = Column(DOUBLE(asdecimal=False))  # 平均规模
-    exchange_status = Column(CHAR(20))  # 交易状态
-    theme = Column(CHAR(20))  # 基金主题
-    track_index = Column(CHAR(20)) # 跟踪指数
-    purch_status = Column(CHAR(16))  # 申购状态
-    redem_status = Column(CHAR(16))  # 赎回状态
+    average_size = Column(DOUBLE(asdecimal=False))  # 平均规模 basic.FundRet.avg_size
+    exchange_status = Column(CHAR(20))  # 交易状态 basic.FundStatusLatest
+    theme = Column(CHAR(20))  # 基金主题 暂无
+    track_index = Column(CHAR(20)) # 跟踪指数 basic.FundInfo.track_index
+    purch_status = Column(CHAR(16))  # 申购状态 basic.FundStatusLatest
+    redem_status = Column(CHAR(16))  # 赎回状态 basic.FundStatusLatest
+    fund_type = Column(CHAR(10))  # 基金人工大类 base on wind_class_II
     lp_limit = Column(DOUBLE(asdecimal=False))  # 暂停大额申购上限
     otc_lp_limit = Column(DOUBLE(asdecimal=False))  # 场外暂停大额申购上限
     otc_lp_limit_jg = Column(DOUBLE(asdecimal=False))  # 场外暂停大额申购上限(机构)
     otc_lp_limit_gr = Column(DOUBLE(asdecimal=False))  # 场外暂停大额申购上限(个人)
 
-    unit_net_value = Column(DOUBLE(asdecimal=False))  # 单位净值
+    # basic.FundNav
+    unit_net_value = Column(DOUBLE(asdecimal=False))  # 单位净值 
     acc_net_value = Column(DOUBLE(asdecimal=False))  # 累计单位净值
     adjusted_net_value = Column(DOUBLE(asdecimal=False))  # 复权净值
     change_rate = Column(DOUBLE(asdecimal=False))  # 日收益率
     found_date = Column(CHAR(20))  # 成立日期
     end_date = Column(CHAR(20))  # 关闭日期
-    annualized_returns = Column(DOUBLE(asdecimal=False))  # 成立以来年化收益率
-    annualized_risk = Column(DOUBLE(asdecimal=False))  # 成立以来年化风险
-    information_ratio = Column(DOUBLE(asdecimal=False))  # 成立以来信息比率
-    last_month_return = Column(DOUBLE(asdecimal=False))  # 近一月收益率
-    last_six_month_return = Column(DOUBLE(asdecimal=False))
+    
+    # basic.FundRet
+    annualized_returns = Column(DOUBLE(asdecimal=False))  # 成立以来年化收益率 
+    annualized_risk = Column(DOUBLE(asdecimal=False))  # 成立以来年化风险 
+    information_ratio = Column(DOUBLE(asdecimal=False))  # 成立以来信息比率 
+    last_month_return = Column(DOUBLE(asdecimal=False))  # 近一月收益率 
+    last_six_month_return = Column(DOUBLE(asdecimal=False)) # 
     last_three_month_return = Column(DOUBLE(asdecimal=False))  # 近一季度收益率
-    last_twelve_month_return = Column(DOUBLE(asdecimal=False))  # 近一年收益率
+    last_twelve_month_return = Column(DOUBLE(asdecimal=False))  # 近一年收益率 
     last_week_return = Column(DOUBLE(asdecimal=False))  # 近一周收益率
     year_to_date_return = Column(DOUBLE(asdecimal=False))  # 今年以来收益率
     to_date_return = Column(DOUBLE(asdecimal=False))  # 成立至今收益率
@@ -58,6 +62,7 @@ class FundDailyCollection(Base):
     y5_ret = Column(DOUBLE(asdecimal=False))  # 近五年收益率
     vol = Column(DOUBLE(asdecimal=False))  # 波动率（成立以来）
 
+    # based on basic.FundRet
     last_week_return_rank = Column(Integer)  # 近一周同类排名
     last_month_return_rank = Column(Integer)  # 近一月同类排名
     last_three_month_return_rank = Column(Integer)  # 近三月同类排名
@@ -69,14 +74,18 @@ class FundDailyCollection(Base):
     to_date_return_rank = Column(Integer)  # 成立以来同类排名
     group_num = Column(Integer)  # 同类数量
 
+    # derived.Derived.FundManagerInfo
     fund_manager = Column(CHAR(255))  # 基金经理
     fund_manager_id = Column(CHAR(127))  # 基金经理ID
     company_name = Column(CHAR(64))  # 基金公司
     symbol = Column(CHAR(64)) # 基金名称
-    benchmark = Column(CHAR(255)) # 业绩基准
+    
+    # basic.FundBenchmark
+    benchmark = Column(CHAR(255)) # 业绩基准  basic.FundInfo.benchmark
     benchmark_s = Column(CHAR(64)) # 跟踪标的id
     benchmark_name = Column(CHAR(64)) # 跟踪标的
 
+    # basic.FundRate
     zs = Column(DOUBLE(asdecimal=False))  # 招商评级
     sh3 = Column(DOUBLE(asdecimal=False))  # 上海证券评级三年期
     sh5 = Column(DOUBLE(asdecimal=False))  # 上海证券评级五年期
@@ -84,6 +93,7 @@ class FundDailyCollection(Base):
     mornstar_3y = Column(DOUBLE(asdecimal=False))  # 晨星三年评级
     mornstar_5y = Column(DOUBLE(asdecimal=False))  # 晨星五年评级
 
+    # basic.FundAlpha
     track_err = Column(DOUBLE(asdecimal=False))  # 跟踪误差
     this_y_alpha = Column(DOUBLE(asdecimal=False))  # 今年以来超额收益
     cumulative_alpha = Column(DOUBLE(asdecimal=False))  # 成立以来超额收益
@@ -96,8 +106,10 @@ class FundDailyCollection(Base):
     y5_alpha = Column(DOUBLE(asdecimal=False))  # 近五年超额收益
     y10_alpha = Column(DOUBLE(asdecimal=False))  # 近十年超额收益
 
+    # basic.FundSize.latest_size
     latest_size = Column(DOUBLE(asdecimal=False)) # 最新规模
 
+    # derived.FundIndicator
     beta = Column(DOUBLE(asdecimal=False))  # 风险指数
     alpha = Column(DOUBLE(asdecimal=False))  # 投资回报
     tag_track_err = Column(DOUBLE(asdecimal=False))  # 跟踪误差
@@ -116,6 +128,7 @@ class FundDailyCollection(Base):
     r_square = Column(DOUBLE(asdecimal=False))  # 决定系数R方
     sharpe = Column(DOUBLE(asdecimal=False))  # 夏普率
 
+    # derived.FundScoreNew
     tag_name = Column(CHAR(64)) # 基金类别
     score = Column(DOUBLE(asdecimal=False)) # 评分
 
@@ -244,6 +257,7 @@ class IndexDailyCollection(Base):
 
     __tablename__ = 'index_daily_collection'
 
+    # derived.IndexValuationLongTerm
     index_id = Column(CHAR(20), primary_key=True)  # 指数ID
     datetime = Column(DATE, primary_key=True)  # 日期
     pb_mrq = Column(DOUBLE(asdecimal=False))  # 市净率-MRQ
@@ -257,6 +271,7 @@ class IndexDailyCollection(Base):
     ps_pct = Column(DOUBLE(asdecimal=False))  # PS百分位
     val_score = Column(DOUBLE(asdecimal=False))  # 估值评分
 
+    # calc based on derived.IndexValuationLongTerm pe_ttm pb_mrq
     pe_0_percentile = Column(DOUBLE(asdecimal=False))  # pe0分位
     pe_30_percentile = Column(DOUBLE(asdecimal=False))  # pe30分位
     pe_70_percentile = Column(DOUBLE(asdecimal=False))  # pe70分位
@@ -266,6 +281,7 @@ class IndexDailyCollection(Base):
     pb_70_percentile = Column(DOUBLE(asdecimal=False))  # pb70分位
     pb_100_percentile = Column(DOUBLE(asdecimal=False))  # pb100分位
 
+    # derived.IndexVolatility
     vol_datetime = Column(DATE)  # 日期
     w1_vol = Column(DOUBLE(asdecimal=False))  # 近一周波动率
     m1_vol = Column(DOUBLE(asdecimal=False))  # 近一月波动率
@@ -278,6 +294,7 @@ class IndexDailyCollection(Base):
     this_y_vol = Column(DOUBLE(asdecimal=False))  # 今年以来波动率
     cumulative_vol = Column(DOUBLE(asdecimal=False))  # 成立至今波动率
 
+    # derived.IndexReturn
     ret_datetime = Column(DATE)  # 日期
     w1_ret = Column(DOUBLE(asdecimal=False))  # 近一周收益率
     m1_ret = Column(DOUBLE(asdecimal=False))  # 近一月收益率
@@ -290,6 +307,7 @@ class IndexDailyCollection(Base):
     this_y_ret = Column(DOUBLE(asdecimal=False))  # 今年以来收益率
     cumulative_ret = Column(DOUBLE(asdecimal=False))  # 成立至今收益率
 
+    # basic.IndexPrice
     price_datetime = Column(DATE)  # 日期
     volume = Column(DOUBLE(asdecimal=False))  # 交易量
     low = Column(DOUBLE(asdecimal=False))  # 最低价
@@ -299,7 +317,8 @@ class IndexDailyCollection(Base):
     total_turnover = Column(DOUBLE(asdecimal=False))  # 成交额
     ret = Column(DOUBLE(asdecimal=False))  # 收益率
     yest_close = Column(DOUBLE(asdecimal=False))  # 前收盘价
-
+    
+    # basic.IndexInfo
     order_book_id = Column(CHAR(20))  # 米筐ID
     industry_tag = Column(CHAR(64))  # 行业标签
     tag_method = Column(CHAR(64))  # 估值评分采用方法
@@ -429,6 +448,7 @@ class AutomaticInvestmentCollection(Base):
 
     __tablename__ = 'automatic_investment_collection'
 
+    # derived.FundAIC
     fund_id = Column(CHAR(20), primary_key=True)  # 基金ID
     price_time = Column(CHAR(20), primary_key=True)  # 时间
     y1_ret = Column(DOUBLE(asdecimal=False))  # 普通定投一年收益
