@@ -1,4 +1,5 @@
 import pandas as pd
+import numpy as np
 import platform
 import matplotlib as mpl
 import pylab as pl
@@ -259,5 +260,25 @@ class AssetPainter(object):
         pl.grid()
         pl.show()
 
+    @staticmethod
+    def plot_index_price_ratio(df,t):
+        df.index = [str(i) for i in df.index]
+        dic = ((df.iloc[-1]-1) * 10000).astype(int).to_dict()
+        m = int(np.mean(list(dic.values())))
+        _st = sorted(dic.items(), key=lambda x:x[1], reverse=True)
+        st_1 = [f'mean diff: {m} BP  ']
+        st_2 = []
+        for i in _st:
+            if i[1] > 0:
+                st_1.append(f'{i[0]}:{i[1]} ')
+            else:    
+                st_2.append(f'{i[0]}:{i[1]} ')
+        st = ''.join(st_1)+'\n'+''.join(st_2)
+        df.plot.line(figsize=(14,8),fontsize=15)
+        plt.legend(fontsize=13, loc='lower left')
+        plt.title(t,fontsize=22)
+        plt.suptitle(st, y=0.87, fontsize=18)
+        plt.grid()
+        plt.show()
 
         
\ No newline at end of file
