@@ -50,6 +50,7 @@ class ReportHelper:
         self.taa_params = taa_helper.params if isinstance(taa_helper, TAAHelper) else None
         self.index_pct = dm.dts.index_pct
         self.dts = dm.dts.trading_days.datetime
+        self.fund_manager_info = dm.dts.fund_manager_info
         self.fund_score_dm = dm._score_manager.score_cache
         trade_list = []
         for d, trade_d in self.trade_history.items():
@@ -222,6 +223,7 @@ class ReportHelper:
             _fund_list = [i[0] for i in _score_list]
             rank_i = _fund_list.index(i.Index) + 1 if i.Index in _fund_list else 10000
             fund_rank.append(rank_i)
+        pos_df = pos_df.join(self.fund_info.set_index('fund_id')[['fund_manager']])
         pos_df.loc[:,'fund_rank'] = fund_rank
         return pos_df
 
@@ -235,8 +237,9 @@ class ReportHelper:
                 'desc_name':fund_info_dic[fund_w.fund_id]}
             res.append(dic)
         target_fund = pd.DataFrame(res).set_index('fund_id')
+        target_fund = target_fund.join(self.fund_info.set_index('fund_id')[['fund_manager']])
         target_fund.index.name = list(self.fund_position_history.keys())[-1]
-        return target_fund.sort_values('weight', ascending = False)[['index_id','weight','desc_name']]
+        return target_fund.sort_values('weight', ascending = False)[['index_id','weight','desc_name','fund_manager']]
 
     def get_fund_trade(self):
         fsdf = self.fund_score.copy()
