@@ -315,7 +315,8 @@ class FundTrader(AssetTrader):
             cur_fund_nav: dict,
             cur_fund_score: dict,
             cur_asset_price: AssetPrice,
-            score_select: dict) -> bool:
+            score_select: dict,
+            fund_end_date_dict: dict) -> bool:
 
         index_rebalance_max_diff = 0
         fund_selection_min_score = 1
@@ -353,7 +354,8 @@ class FundTrader(AssetTrader):
             _fund_list = self.pos_manager_list if index_id == 'active' else c.cur_fund_ids     
             for f in _fund_list:
                 rank_i = c.fund_ranks.get(f, self.BIG_INT)
-                if rank_i == self.BIG_INT:
+                _end_date = fund_end_date_dict.get(f)
+                if _end_date <= dt or rank_i == self.BIG_INT:
                     fund_end = 1
                 _rank_list.append((f, rank_i))
                 c.fund_judge_ranking_score += wgt_func(rank_i)
@@ -436,7 +438,8 @@ class FundTrader(AssetTrader):
             cur_fund_unit_nav: dict,
             is_real_trade: bool,
             cur_manager_funds: dict,
-            score_select: dict) -> list:
+            score_select: dict,
+            fund_end_date_dict: dict) -> list:
         '''
         v_asset_position, asset_trade_list = self.calc_asset_trade(dt, cur_asset_position, cur_asset_price, tar_asset_weight)
         if not asset_trade_list:
@@ -452,12 +455,12 @@ class FundTrader(AssetTrader):
             trigger, trigger_reason = self.judge_trade(dt, index_fund_cache, 
                                         tar_fund_weight, tar_asset_weight,
                                         cur_fund_position, cur_asset_position, cur_fund_unit_nav, 
-                                        cur_fund_score, cur_asset_price, score_select)
+                                        cur_fund_score, cur_asset_price, score_select, fund_end_date_dict)
         else:
             trigger, trigger_reason = self.judge_trade(dt, index_fund_cache, 
                                         tar_fund_weight, tar_asset_weight,
                                         cur_fund_position, cur_asset_position, cur_fund_nav, 
-                                        cur_fund_score, cur_asset_price, score_select)
+                                        cur_fund_score, cur_asset_price, score_select, fund_end_date_dict)
         
         # 如果是真实交易 且cash 不为零，按照当日cash，返回买单
         if (is_real_trade is False and trigger == 0) or (is_real_trade is True and cur_fund_position.cash == 0 and trigger == 0):
@@ -542,9 +545,16 @@ class FundTrader(AssetTrader):
                             fund_unit_nav=cur_fund_unit_nav[fund_id],
                             fund_unit_volume=_amt/cur_fund_unit_nav[fund_id],
                         )
+                    # 如果一个基金属于多个资产类别导致重复下单，只下一次
+                    _is_duplicate_fund = False
+                    for _t in fund_trades:
+                        if fund_id == _t.fund_id:
+                            _is_duplicate_fund = True
+                    if _is_duplicate_fund:
+                        continue
                     fund_trades.append(_trade)
                     # print(f'(fund){fund_id} (d){"buy" if is_buy else "sell"} (r){c.fund_ranks.get(fund_id, -1)} (p){p} (amt){target_fund_amt - cur_fund_amt} (tar){target_fund_amt} (ind){index_id}')
-        
+
         if is_real_trade and cur_fund_position.cash > 0 :
             #如果是真实交易，现金不为0， 按照cash值调整买单交易量，只返回买单
             buy_trades_amt = sum([i.amount for i in fund_trades if i.is_buy is True])
