@@ -14,29 +14,27 @@ class Factor(metaclass=Singleton):
 
     def __init__(self, f_name: str, f_type: StockFactorType):
         self._f_name: str = f_name
+        self._s3_file_name: str = f'{f_name}.parquet'
         self._f_type: StockFactorType = f_type
-        self._s3_uri: str = f's3://{_BUCKET_NAME}/factor/{f_name}.parquet'
-        self._s3_uri_factor_ret: str = f's3://{_BUCKET_NAME}/factor_ret/{f_name}.parquet'
+        self._s3_uri: str = f's3://{_BUCKET_NAME}/factor/' + self._s3_file_name
+        self._s3_uri_factor_ret: str = f's3://{_BUCKET_NAME}/factor_ret/'
         self._factor: Optional[pd.DataFrame] = None
 
     # @lru_cache
-    def get(self, universe=None) -> Optional[pd.DataFrame]:
+    def get(self, universe: str = 'default') -> Optional[pd.DataFrame]:
+        # 这里我们认为没有必要去存储各个universe下的因子值
+        # 因为只要全量(default)的因子值保存了，使用stock_list去过滤出相应universe下的因子值会非常快
         if self._factor is None:
             self._load_data()
-        if universe is not None:
-            if not isinstance(universe, Universe):
-                assert False, f'universe should be an instance of Universe, not {type(universe)}'
-            stock_list = universe.get()
-            return self._factor.loc[:, stock_list]
+        if universe != 'default':
+            stock_list = Universe().get(universe)
+            if stock_list is not None:
+                return self._factor.loc[:, stock_list]
+            print(f'get data of universe {universe} failed, use default universe')
         return self._factor
 
-    def get_normalized(self, universe=None):
-        data = self.get()
-        if universe is not None:
-            if not isinstance(universe, Universe):
-                assert False, f'universe should be an instance of Universe, not {type(universe)}'
-            stock_list = universe.get()
-            data = data.loc[:, stock_list]
+    def get_normalized(self, universe: str = 'default'):
+        data = self.get(universe)
         return ((data.T - data.mean(axis=1))/data.std(axis=1)).T
 
     @property
@@ -64,3 +62,6 @@ class Factor(metaclass=Singleton):
             print(f'retrieve data from s3 failed, (err_msg){e}; try to re-calc')
             self.calc()
         return self._factor
+
+    def _get_s3_factor_ret_uri(self, universe: str) -> str:
+        return f'{self._s3_uri_factor_ret}{universe}/{self._s3_file_name}'
