@@ -1,4 +1,6 @@
 
+import numpy as np
+
 from .factor_types import LeverageFactor
 from .basic_factors import FloatAssetAvgFactor, FloatDebtAvgFactor, FixAssetAvgFactor, TotalDebtAvgFactor, CashFlowTTMFactor
 
@@ -10,7 +12,7 @@ class FloatRatioFactor(LeverageFactor):
 
     def calc(self):
         # 企业的流动资产除以流动负债
-        self._factor = FloatAssetAvgFactor().get() / FloatDebtAvgFactor().get()
+        self._factor = FloatAssetAvgFactor().get() / FloatDebtAvgFactor().get().replace({0: np.nan})
 
 
 class StockDebtRatioFactor(LeverageFactor):
@@ -20,7 +22,7 @@ class StockDebtRatioFactor(LeverageFactor):
 
     def calc(self):
         # 企业的净资产除以总债务
-        self._factor = FixAssetAvgFactor().get() / TotalDebtAvgFactor().get()
+        self._factor = FixAssetAvgFactor().get() / TotalDebtAvgFactor().get().replace({0: np.nan})
 
 
 class CashFlowRatioFactor(LeverageFactor):
@@ -30,14 +32,18 @@ class CashFlowRatioFactor(LeverageFactor):
 
     def calc(self):
         # 过去四个季度的经营现金流除以流动负债
-        self._factor = CashFlowTTMFactor().get() / FloatDebtAvgFactor().get()
+        self._factor = CashFlowTTMFactor().get() / FloatDebtAvgFactor().get().replace({0: np.nan})
 
 
 class MixLeverageFactor(LeverageFactor):
     # 合成因子
-    def __init__(self, universe=None):
+    def __init__(self):
         super().__init__('mixl')
-        self.universe = universe
+        self._universe: str = 'default'
+
+    # TODO: 这个接口写的不好，暂时先这样
+    def set_universe(self, universe: str):
+        self._universe = universe
 
     def calc(self):
-        self._factor = FloatRatioFactor().get_normalized(self.universe) + StockDebtRatioFactor().get_normalized(self.universe) + CashFlowRatioFactor().get_normalized(self.universe)
+        self._factor = FloatRatioFactor().get_normalized(self._universe) + StockDebtRatioFactor().get_normalized(self._universe) + CashFlowRatioFactor().get_normalized(self._universe)
