@@ -46,9 +46,13 @@ class Turnover90DFactor(TurnoverDateFactor):
 
 class MixLiquidityFactor(LiquidityFactor):
     # 合成因子
-    def __init__(self, universe=None):
+    def __init__(self):
         super().__init__('mixl')
-        self.universe = universe
+        self._universe: str = 'default'
+
+    # TODO: 这个接口写的不好，暂时先这样
+    def set_universe(self, universe: str):
+        self._universe = universe
 
     def calc(self):
-        self._factor = Turnover30DFactor().get_normalized(self.universe) + Turnover60DFactor().get_normalized(self.universe) + Turnover90DFactor().get_normalized(self.universe)
+        self._factor = Turnover30DFactor().get_normalized(self._universe) + Turnover60DFactor().get_normalized(self._universe) + Turnover90DFactor().get_normalized(self._universe)
