@@ -4,6 +4,7 @@ from datetime import date
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
+import math
 import scipy.optimize
 
 def xnpv(rate, values, dates):
@@ -15,7 +16,7 @@ def xnpv(rate, values, dates):
     >>> xnpv(0.1, values, dates)
     -966.4345...
     '''
-    if rate <= -1.0:
+    if rate < -1.0 or math.isclose(rate,-1,rel_tol=1e-09):
         return float('inf')
     d0 = dates[0]    # or min(dates)
     return sum([ vi / (1.0 + rate)**((di - d0).days / 365.0) for vi, di in zip(values, dates)])
