@@ -7,6 +7,8 @@ import statsmodels.api as sm
 from statsmodels import regression
 from scipy.stats import gmean
 from functools import partial
+import statsmodels.api as sm
+from statsmodels.tsa.ar_model import AutoReg
 from ..data.api.basic import BasicDataApi
 from ..data.struct import TAAParam, TaaTunerParam, AssetWeight
 from ..data.api.derived import DerivedDataApi
@@ -30,12 +32,16 @@ class SeriesStatUnit:
     mdd: float                  # 最大回撤
     mdd_date1: datetime.date    # 最大回撤开始时间
     mdd_date2: datetime.date    # 最大回撤结束时间
+    mdd_lens: int               # 最大回撤区间持续时间
     ret_over_mdd: float         # Calmar 年化收益除以最大回撤
     last_mv_diff: float         # 末期市值增量              
     last_increase_rate: float   # 末期涨幅
     worst_3m_ret: float         # 最差三月收益
     worst_6m_ret: float         # 最差六月收益
     recent_drawdown: float      # 最近回撤
+    downside_std :float         # 下行风险
+    var : float                 # 风险价值VaR
+    cvar: float                 # 条件风险价值 CVaR
 
 @dataclasses.dataclass
 class BenchmarkSeiesStatUnit(SeriesStatUnit):
@@ -44,6 +50,11 @@ class BenchmarkSeiesStatUnit(SeriesStatUnit):
     beta: float                 # 风险暴露
     track_err: float            # 跟踪误差
     ir: float                   # 信息比率
+    alpha_cl: float             # 择股收益
+    beta_cl: float              # 择时收益
+    treynor: float              # 特雷诺
+    win_rate: float             # 胜率
+    continue_value: float       # 业绩持续性
 
 class Calculator:
 
@@ -67,6 +78,11 @@ class Calculator:
         if frequency == 'yearly':
             return 242
 
+    @staticmethod
+    def get_datatime_date(dt):
+        dt = dt if isinstance(dt, datetime.datetime) else pandas.to_datetime(dt).date()
+        return dt
+
     @staticmethod
     def get_stat_result(dates: pandas.core.series.Series,
                         values: pandas.core.series.Series,
@@ -75,6 +91,7 @@ class Calculator:
         
         if len(dates) > 1:
             sr = pandas.Series(values, index=dates).sort_index()
+            sr_ret = sr.pct_change(1)
             risk_fee_rate = Calculator.get_risk_free_rate()
             start_date = sr.index[0] 
             end_date = sr.index[-1]
@@ -101,12 +118,21 @@ class Calculator:
             if np.isnan(mdd):
                 mdd_date2 = None
                 mdd_date1 = None
+                mdd_lens = None
             else:
                 mdd_date2 = mdd_part.idxmin()
                 mdd_date1 = sr[:mdd_date2].idxmax()
+                _mdd_date1 = Calculator.get_datatime_date(mdd_date1)
+                _mdd_date2 = Calculator.get_datatime_date(mdd_date2)
+                mdd_lens = (_mdd_date2-_mdd_date1).days
+            
             ret_over_mdd = annualized_ret / mdd if mdd != 0 else None
             last_mv_diff = sr[-1] - sr[-2]
             last_increase_rate = (sr[-1] - sr[-2])/ sr[-2]
+            risk_free_period = risk_fee_rate / Calculator.TRADING_DAYS_PER_YEAR * yearly_multiplier
+            downside_std = sr_ret[sr_ret < risk_free_period].std(ddof=1)
+            var = np.quantile(sr_ret, 0.05)
+            cvar = sr_ret[sr_ret <= var].mean()
         # 如果只输入一天，返回空
         else:
             start_date = dates[0] if len(dates) > 0 else None
@@ -121,12 +147,16 @@ class Calculator:
             mdd = 0
             mdd_date1 = dates[0] if len(dates) > 0 else None
             mdd_date2 = dates[0] if len(dates) > 0 else None
+            mdd_lens = 0
             ret_over_mdd = 0
             last_mv_diff = 0
             last_increase_rate = 0
             recent_drawdown = 0
             worst_3m_ret = 0
             worst_6m_ret = 0
+            downside_std = 0
+            var = 0
+            cvar = 0
 
         return SeriesStatUnit(
             start_date=start_date,
@@ -143,10 +173,14 @@ class Calculator:
             mdd=mdd,
             mdd_date1=mdd_date1,
             mdd_date2=mdd_date2,
+            mdd_lens=mdd_lens,
             ret_over_mdd=ret_over_mdd,
             last_mv_diff=last_mv_diff,
             last_increase_rate=last_increase_rate,
             recent_drawdown=recent_drawdown,
+            downside_std=downside_std,
+            var=var,
+            cvar=cvar,
         )
 
     @staticmethod
@@ -208,6 +242,19 @@ class Calculator:
         x = sr_benchmark_ret.dropna().values
         y = sr_values_ret.dropna().values
         x = sm.add_constant(x)
+        if x.shape[1] < 2:
+            return {
+                'start_date': res['start_date'],
+                'end_date': res['end_date'],
+                'trade_year':res['trade_year'],
+                'annualized_ret':res['annualized_ret'],
+                'annualized_vol':res['annualized_vol'],
+                'sharpe':res['sharpe'],
+                'mdd':res['mdd'],
+                'alpha':np.nan,
+                'beta':np.nan,
+                'track_err':np.nan,
+            }
         model = regression.linear_model.OLS(y,x).fit()
         x = x[:,1]
         alpha = model.params[0] * Calculator.TRADING_DAYS_PER_YEAR / yearly_multiplier
@@ -227,6 +274,41 @@ class Calculator:
                 'track_err':track_err,
         }
 
+    @staticmethod
+    def calc_cl_alpha_beta(total: np.ndarray):
+        if total.shape[0] <= 1:
+            return {'beta':np.nan,
+                    'alpha':np.nan,
+                    }
+        X = np.array([total[:, 1], total[:, 1]]).T
+        X[:, 0][X[:, 0] < 0] = 0
+        X[:, 1][X[:, 1] > 0] = 0
+        if np.count_nonzero(X[:, 1]) == 0:
+            return {'beta':np.nan,
+                    'alpha':np.nan,
+                    }
+        est2 = sm.OLS(total[:, 0], sm.add_constant(X, prepend=False)).fit()
+        return {'beta':est2.params[0] - est2.params[1],
+                'alpha':est2.params[-1],
+                }
+    
+    @staticmethod
+    def calc_continue_regress_v(monthly_ret):
+        # 半年周期
+        window = 6
+        yearly_multiplier = 2
+        period_num = 12
+        risk_fee_rate = Calculator.get_risk_free_rate()
+        annual_ret = monthly_ret.rolling(window=window).apply(lambda x : x.sum() * yearly_multiplier - risk_fee_rate)
+        annual_vol = monthly_ret.rolling(window=window).apply(lambda x : x.std(ddof=1) * np.sqrt(period_num))
+        sharpe = (annual_ret / annual_vol)
+        sharpe = sharpe.replace(np.Inf, np.nan).replace(-np.Inf, sharpe).dropna() # 空值sharpe赋值np.nan
+        if sharpe.shape[0] < 6:
+            return np.nan
+        mod = AutoReg(endog=sharpe.values, lags=1)
+        res = mod.fit()
+        continue_regress_v = res.params[0]
+        return continue_regress_v
 
     @staticmethod
     def get_benchmark_stat_result(dates: pandas.core.series.Series,
@@ -239,21 +321,70 @@ class Calculator:
         res = Calculator.get_stat_result(dates, values,frequency)
         sr_values  = pandas.Series(values, index=dates).sort_index()  
         sr_values = sr_values / sr_values[0]
+        sr_values.name = 'fund'
         sr_benchmark_values = pandas.Series(benchmark_values, index=dates).sort_index()  
         sr_benchmark_values = sr_benchmark_values / sr_benchmark_values[0]
+        sr_benchmark_values.name = 'benchmark'
         yearly_multiplier = Calculator.get_yearly_multiplier(frequency)
         sr_values_ret = sr_values.pct_change(1)
         sr_benchmark_ret = sr_benchmark_values.pct_change(1)
         x = sr_benchmark_ret.dropna().values
         y = sr_values_ret.dropna().values
+        ex_ret = y - x
+        win_rate = len(ex_ret[ex_ret > 0]) / len(ex_ret)
         x = sm.add_constant(x)
+        if x.shape[1] < 2:
+            return BenchmarkSeiesStatUnit(
+                start_date=res.start_date,
+                end_date=res.end_date,
+                trade_year=res.trade_year,
+                last_unit_nav=res.last_unit_nav,
+                annualized_ret=res.annualized_ret,
+                annualized_vol=res.annualized_vol,
+                sharpe=res.sharpe,
+                recent_y5_ret=res.recent_y5_ret,
+                mdd=res.mdd,
+                mdd_date1=res.mdd_date1,
+                mdd_date2=res.mdd_date2,
+                mdd_lens=res.mdd_lens,
+                ret_over_mdd=res.ret_over_mdd,
+                alpha=np.nan,
+                beta=np.nan,
+                track_err=np.nan,
+                ir=np.nan,
+                last_mv_diff=res.last_mv_diff,
+                last_increase_rate=res.last_increase_rate,
+                recent_y1_ret=res.recent_y1_ret,
+                worst_3m_ret=res.worst_3m_ret,
+                worst_6m_ret=res.worst_6m_ret,
+                recent_drawdown=res.recent_drawdown,
+                downside_std=res.downside_std,
+                var=res.var,
+                cvar=res.cvar,
+                win_rate=np.nan,
+                treynor=np.nan,
+                alpha_cl=np.nan,
+                beta_cl=np.nan,
+                continue_value=np.nan,
+        )
         model = regression.linear_model.OLS(y,x).fit()
         x = x[:,1]
         alpha = model.params[0] * Calculator.TRADING_DAYS_PER_YEAR / yearly_multiplier
         beta = model.params[1]
         track_err = (sr_values_ret - sr_benchmark_ret).std(ddof=1) * np.sqrt(Calculator.TRADING_DAYS_PER_YEAR / yearly_multiplier)
         ir = alpha / track_err
-        
+        risk_fee_rate = Calculator.get_risk_free_rate()
+        risk_free_period = risk_fee_rate / Calculator.TRADING_DAYS_PER_YEAR * yearly_multiplier
+        treynor = (np.nanmean(y) - risk_free_period) / beta if beta != 0 else np.nan
+        df = pandas.concat([sr_values,sr_benchmark_values],axis=1)
+        df_monthly = df.set_axis(pandas.to_datetime(df.index), inplace=False).resample(rule='1M').last()
+        df_monthly.index = df_monthly.index.date
+        monthly_ret = df_monthly.pct_change(1).dropna()
+        cl_res = Calculator.calc_cl_alpha_beta(monthly_ret.to_numpy())
+        alpha_cl = cl_res['alpha']
+        beta_cl = cl_res['beta']
+        continue_value = Calculator.calc_continue_regress_v(monthly_ret.fund)
+
         return BenchmarkSeiesStatUnit(
             start_date=res.start_date,
             end_date=res.end_date,
@@ -266,6 +397,7 @@ class Calculator:
             mdd=res.mdd,
             mdd_date1=res.mdd_date1,
             mdd_date2=res.mdd_date2,
+            mdd_lens=res.mdd_lens,
             ret_over_mdd=res.ret_over_mdd,
             alpha=alpha,
             beta=beta,
@@ -277,6 +409,14 @@ class Calculator:
             worst_3m_ret=res.worst_3m_ret,
             worst_6m_ret=res.worst_6m_ret,
             recent_drawdown=res.recent_drawdown,
+            downside_std=res.downside_std,
+            var=res.var,
+            cvar=res.cvar,
+            win_rate=win_rate,
+            treynor=treynor,
+            alpha_cl=alpha_cl,
+            beta_cl=beta_cl,
+            continue_value=continue_value,
         )
 
     @staticmethod
@@ -415,7 +555,6 @@ class Calculator:
         df_result = df_result.rename(columns = {asset_func_index:'status'})
         return df_result.to_dict('records') 
 
-
     @staticmethod
     def get_val_level(x):
         val_dict = {
