@@ -1,5 +1,5 @@
 
-from typing import Dict, List
+from typing import Dict, List, Set, Optional
 import requests
 import json
 from .config import SurfingConfigurator
@@ -39,7 +39,7 @@ class WechatBot(object):
 
         return self.send(markdown_content)
 
-    def send_new_fund_list(self, dt, new_funds: Dict[str, str], new_delisted_funds: Dict[str, str]):
+    def send_new_fund_list(self, dt, new_funds: Dict[str, str], new_delisted_funds: Dict[str, str], indexes_that_become_invalid: Optional[Set[str]]):
         markdown_content = f'#### {dt}'
         if new_funds is None or new_delisted_funds is None:
             markdown_content += f' **<font color=\"warning\">获取今日新基金或摘牌基金列表失败</font>**'
@@ -52,6 +52,8 @@ class WechatBot(object):
                 markdown_content += f'\n\n>摘牌基金({len(new_delisted_funds)}): <font color=\"info\">{new_delisted_funds}</font>'
             else:
                 markdown_content += f'\n\n>无摘牌基金'
+        if indexes_that_become_invalid is not None and indexes_that_become_invalid:
+            markdown_content += f'\n\n\n>**失效指数({len(indexes_that_become_invalid)}, 请注意处理!!): <font color=\"warning\">{indexes_that_become_invalid}</font>**'
         self.send(markdown_content)
 
     def send_dump_to_s3_result(self, dt, failed_tables: List[str], failed_dfs: List[str]):
